Index: Source/core/css/AffectedByFocusTest.cpp |
diff --git a/Source/core/css/AffectedByFocusTest.cpp b/Source/core/css/AffectedByFocusTest.cpp |
index 9198abc4ea353f460b8d52bda73d7e49c410443a..e3bf990fe47d4cabe7505121ce2bb435ce499cb4 100644 |
--- a/Source/core/css/AffectedByFocusTest.cpp |
+++ b/Source/core/css/AffectedByFocusTest.cpp |
@@ -6,7 +6,7 @@ |
#include "core/HTMLNames.h" |
#include "core/dom/Element.h" |
#include "core/dom/ElementTraversal.h" |
-#include "core/dom/NodeLayoutStyle.h" |
+#include "core/dom/NodeComputedStyle.h" |
#include "core/dom/StyleEngine.h" |
#include "core/frame/FrameView.h" |
#include "core/html/HTMLDocument.h" |
@@ -63,8 +63,8 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec |
for (; element && i < expectedCount; element = Traversal<HTMLElement>::next(*element), ++i) { |
ASSERT_TRUE(element->hasTagName(expected[i].tag)); |
- ASSERT(element->layoutStyle()); |
- ASSERT_EQ(expected[i].affectedBy, element->layoutStyle()->affectedByFocus()); |
+ ASSERT(element->computedStyle()); |
+ ASSERT_EQ(expected[i].affectedBy, element->computedStyle()->affectedByFocus()); |
ASSERT_EQ(expected[i].childrenOrSiblingsAffectedBy, element->childrenOrSiblingsAffectedByFocus()); |
} |
@@ -73,7 +73,7 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec |
// A global :focus rule in html.css currently causes every single element to be |
// affectedByFocus. Check that all elements in a document with no :focus rules |
// gets the affectedByFocus set on LayoutStyle and not childrenOrSiblingsAffectedByFocus. |
TEST_F(AffectedByFocusTest, UAUniversalFocusRule) |
{ |
ElementResult expected[] = { |
@@ -73,7 +73,7 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec |
// A global :focus rule in html.css currently causes every single element to be |
// affectedByFocus. Check that all elements in a document with no :focus rules |
-// gets the affectedByFocus set on LayoutStyle and not childrenOrSiblingsAffectedByFocus. |
+// gets the affectedByFocus set on ComputedStyle and not childrenOrSiblingsAffectedByFocus. |
TEST_F(AffectedByFocusTest, UAUniversalFocusRule) |
{ |